/****************************************************************************************
 *   Copyright (C) 2011 Christian "Cebra" Brandtner, brandtner@brandtner.net            *
 *                                                                                      *
 *   This program is free software; you can redistribute it and/or modify               *
 *   it under the terms of the GNU General Public License as published by               *
 *   the Free Software Foundation; either version 2 of the License.                     *
 *                                                                                      *
 *   This program is distributed in the hope that it will be useful,                    *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of                     *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                      *
 *   GNU General Public License for more details.                                       *
 *                                                                                      *
 *   You should have received a copy of the GNU General Public License                  *
 *   along with this program; if not, write to the                                      *
 *   Free Software Foundation, Inc.,                                                    *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.                          *
 *                                                                                      *
 *                                                                                      *
 *   Languagesupport:                                                                   *
 *   http://www.netrino.com/Embedded-Systems/How-To/Firmware-Internationalization       *
 *   Nigel Jones                                                                        *
 ****************************************************************************************/


#include "cpu.h"
#include <avr/io.h>
#include <inttypes.h>
#include <stdlib.h>
#include <avr/pgmspace.h>
#include <avr/wdt.h>
#include <util/delay.h>
#include "main.h"
#include "lcd.h"
#include "timer.h"
#include "eeprom.h"
#include "messages.h"




typedef enum
{
	GERMAN,
	ENGLISH,
	FRENCH,
	NETHERLAND,
	LAST_LANGUAGE,

} LANGUAGE;



typedef struct
{
	/*
	* Maximum length
	*/
	int const len;

	/*
	* Array of pointers to language-specific string
	*/
	char const * const text[LAST_LANGUAGE];

} STRING;


//--------------------------------------------------------------------------------------------------------------------
// Typdefinitionen fr alle verwendeten Strings, LAST_STR muss am Ende stehen bleiben
//typedef enum
//TESTSTRING, KEYLINE1, KEYLINE2, KEYLINE3, KEYLINE4, KEYLINE5, BOOT1, BOOT2, BOOT_WI1, BOOT_WI2, BOOT_SV, START_MSG1, START_MSG2, GNU_GPL, ATMEGA644,
//ATMEGA644P, ATMEGA1284P, HW12, HW12W, HW13, HW13W, HW39, START_LASTPOS, START_LASTPOS1, START_LASTPOS2, START_LASTPOS3, START_LASTPOSDEL,
//START_SEARCHFC, ENDE, OK, FEHLER, AKTIV, START_FCNOTFOUND, START_FCFOUND, START_FCFOUND1, START_FCFOUND2, START_FCFOUND3, START_VERSIONCHECK,
//START_VERSIONCHECK1, START_VERSIONCHECK2, START_VERSIONCHECK3, START_VERSIONCHECK4, START_VERSIONCHECK5, ON, OFF, ESC, SHUTDOWN, YESNO,
//UPDATE1, UPDATE2, ENDSTART, TOOLS1, CONNECT1, CONNECT2, CONNECT4, CONNECT5, CONNECT6, CONNECT7, CONNECT8, CONNECT9, CONNECT10, CONNECT11, CONNECT12,
//CONNECT13, CONNECT14, CONNECT15, CONNECT16, CONNECT17, CONNECT18, CONNECT19, CONNECT20, CONNECT21, CONNECT22, CONNECT23, CONNECT24, CONNECT25,
//CONNECT26, CONNECT27, CONNECT28, CONNECT29, CONNECT30, CONNECT31, KABEL, SLAVE, NORMAL, REVERSE, ENDOK, EEPROM1, EEPROM2, DEUTSCH, ENGLISCH, FRANCE,
//NETHERL, DISPLAY1, DISPLAY2, DISPLAY3, DISPLAY4, DISPLAY5, DISPLAY6, DISPLAY7, DISPLAY8, DISPLAY9, DEBUGPKT, WITXRX, WINETWG, WINETWM, WITIMEOUT,
//WIUART, WI2321, WI2322, WI2323, YES, NOO, BT1, BT2, BT3, BT4, LIPO1, LIPO2, LIPO3, LIPO4, LIPO5, LIPO6, LOWBAT, OSD_3D_V, OSD_3D_H, OSD_3D_L,
//OSD_3D_R, OSD_3D_NICK, OSD_3D_ROLL, OSD_3D_COMPASS, OSD_ERROR, OSD_POS1, OSD_POS2, PARA_SETTINGS, PARA_CHANGE, PARA_AKTIVI, PARA_AKTIV,
//PARA_SAVESETT, PARA_SETTSAVED, PARA_COPY, PARA_FROMTO, PARA_ENDE, PARA_COPYQ, PARA_COPYACTIV, PARA_CHANGESETT, PARA_SELECT, PARA_SEITE,
//PARA_SELSETT, GPS1, GPS2, GPS3, STATS_ITEM_0, STATS_ITEM_1, STATS_ITEM_2, STATS_ITEM_3, STATS_ITEM_4, STATS_ITEM_5, STATS_ITEM_6, STATS_ITEM_7,
//STATS_ITEM_8, ONLY_NC, NO_SETTINGS, OSD_ALTI_0, OSD_ALTI_1, OSD_VARIO_0, OSD_VARIO_1, OSD_CARE_FREE_0, OSD_CARE_FREE_1, OSD_LED0, OSD_LED1, OSD_LED2,
//OSD_NAVI_MODE_0, OSD_NAVI_MODE_1, OSD_NAVI_MODE_2, OSD_FLAGS_0, OSD_FLAGS_1, OSD_FLAGS_2, OSD_FLAGS_3, OSD_FLAGS_4, OSD_FLAGS_5, OSD_FLAGS_6,
//OSD_Screen, OSD_Invert_Out, OSD_LED_Form, OSD_Send_OSD, LAST_STR,



static const STRING strings[LAST_STR] =
{
	{ /*TESTSTRING*/
		21,
		{
			"Not format hardisk C?",		/* German */
			"Not format hardisk C?",		/* English*/
			"Not format hardisk C?",		/* French */
			"Not format hardisk C?",		/* Dutch  */

		}
	},

	{ /*KEYLINE1*/
		21,
		{
			" \x1a     \x1b    Ende   OK",	/* German */
			" \x1a     \x1b    end    OK",	/* English*/
			" \x1a     \x1b    fin    OK",	/* French */
			" \x1a     \x1b    Einde  OK",	/* Dutch  */

		}
	},

	{ /*KEYLINE2*/
		21,
		{
			" \x18     \x19    Ende   OK",	/* German */
			" \x18     \x19    end    OK",	/* English*/
			" \x18     \x19    fin    OK",	/* French */
			" \x18     \x19    Einde  OK",	/* Dutch  */

		}
	},

	{ /*KEYLINE3*/
		21,
		{
			" \x18     \x19    Ende ",		/* German */
			" \x18     \x19    end  ",		/* English*/
			" \x18     \x19    fin  ",		/* French */
			" \x18     \x19    Einde",		/* Dutch  */

		}
	},

	{ /*KEYLINE4*/
		21,
		{
			"Ende   OK",					/* German */
			"end    OK",					/* English*/
			"fin    OK",					/* French */
			"Einde  OK",					/* Dutch  */

		}
	},

	{ /*KEYLINE5*/
		21,
		{
			"Ende Info",	/* German */
			"end  info",	/* English*/
			"fin  info",	/* French */
			"Eind Info",	/* Dutch  */

		}
	},

	{ /*BOOT1*/
		21,
		{
			"Taste 1 Sekunde",				/* German */
			"Keep the button",				/* English*/
			"Maintenez le bouton",			/* French */
			"Houd de knop   ",				/* Dutch  */

		}
	},

	{ /* BOOT2*/
		21,
		{
			"lang festhalten.",				/* German */
			"pressed for 1 second",			/* English*/
			"enfoncee pend. 1 sec",			/* French */
			"1 seconde ingedrukt.",			/* Dutch  */
		}
	},

	{ /*BOOT_WI1*/
		21,
		{
			"Verbindung zum MK ist",		/* German */
			"Connection to MK is",			/* English*/
			"Connexion  MK est",			/* French */
			"Verbinding met MK is",			/* Dutch  */

		}
	},

	{ /* BOOT_WI2*/
		21,
		{
			"auf Wi232 eingestellt",		/* German */
			"set to Wi232",					/* English*/
			"mis a Wi232",					/* French */
			"ingesteld op Wi232",			/* Dutch  */
		}
	},

	{ /*BOOTSV1*/
		21,
		{
			"auf Kabel eingestellt",		/* German */
			"set to kabel on SV2",			/* English*/
			"mis a kabel sur SV2",			/* French */
			"via kabelverbinding",			/* Dutch  */

		}
	},

	{ /*START_MSG1 */
		21,
		{
			"Portables Kopter Tool",		/* German */
			"Portable Kopter Tool ",		/* English*/
			"Portable Kopter Tool ",		/* French */
			"Portable Kopter Tool ",		/* Dutch  */

		}
	},

	{ /*START_MSG2 */
		21,
		{
			"fr FC Ver "FC_Version,		/* German */
			"for FC Ver "FC_Version,		/* English*/
			"pour FC Ver "FC_Version,		/* French */
			"Voor FC Ver "FC_Version,		/* Dutch  */
		}
	},

	{ /* GNU/GPL */
		21,
		{
			"GNU GPL License",				/* German */
			"GNU GPL License",				/* English*/
			"GNU GPL License",				/* French */
			"GNU GPL License",				/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"ATmega 644",					/* German */
			"ATmega 644",					/* English*/
			"ATmega 644",					/* French */
			"ATmega 644",					/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"ATmega 644P",					/* German */
			"ATmega 644P",					/* English*/
			"ATmega 644P",					/* French */
			"ATmega 644P",					/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"ATmega 1284P",					/* German */
			"ATmega 1284P",					/* English*/
			"ATmega 1284P",					/* French */
			"ATmega 1284P",					/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"Hardware 1.2",					/* German */
			"Hardware 1.2",					/* English*/
			"Hardware 1.2",					/* French */
			"Hardware 1.2",					/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"Hardware 1.2W",				/* German */
			"Hardware 1.2W",				/* English*/
			"Hardware 1.2W",				/* French */
			"Hardware 1.2W",				/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"Hardware 1.3",					/* German */
			"Hardware 1.3",					/* English*/
			"Hardware 1.3",					/* French */
			"Hardware 1.3",					/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"Hardware 1.3W",				/* German */
			"Hardware 1.3W",				/* English*/
			"Hardware 1.3W",				/* French */
			"Hardware 1.3W",				/* Dutch  */
		}
	},

	{ /**/
		21,
		{
			"Hardware 3.9",					/* German */
			"Hardware 3.9",					/* English*/
			"Hardware 3.9",					/* French */
			"Hardware 3.9",					/* Dutch  */
		}
	},

	{ /*START_LASTPOS*/
		21,
		{
			"   Letzte Position   ",		/* German */
			"   last   position   ",		/* English*/
			"   derniere position ",		/* French */
			"   Laatste positie   ",		/* Dutch  */
		}
	},

	{ /*START_LASTPOS1*/
		21,
		{
			" Breitengr  Lngengr ",		/* German */
			" latitude  longitude ",		/* English*/
			" latitude  longitude ",		/* French */
			"breedtegr. lengtegr. ",		/* Dutch  */
		}
	},

	{ /*START_LASTPOS2*/
		21,
		{
			"lschen        weiter",		/* German */
			"delete          exit ",		/* English*/
			"supprimer       plus ",		/* French */
			"wissen         verder",		/* Dutch  */
		}
	},

	{ /*START_LASTPOS3*/
		21,
		{
			"    Google Eingabe   ",		/* German */
			"    Google Input     ",		/* English*/
			"    Google Input     ",		/* French */
			"    Google Input     ",		/* Dutch  */
		}
	},

	{ /*START_LASTPOSDEL*/
		21,
		{
			"      gelscht       ",		/* German */
			"      deleted        ",		/* English*/
			"      supprime       ",		/* French */
			"      gewist         ",		/* Dutch  */
		}
	},

	{ /*START_SEARCHFC*/
		21,
		{
			"Suche FC...    ",				/* German */
			"searching FC...",				/* English*/
			"cherchant FC...",				/* French */
			"zoek FC...     ",				/* Dutch  */
		}
	},

	{ /*ENDE*/
		21,
		{
			"Ende ",						/* German */
			"end  ",						/* English*/
			"fin  ",						/* French */
			"Einde",						/* Dutch  */
		}
	},

	{ /*OK*/
		21,
		{
			"Ok  ",							/* German */
			"ok  ",							/* English*/
			"ok  ",							/* French */
			"gued",							/* Dutch  */
		}
	},

	{ /*FEHLER*/
		21,
		{
			"Fehler  ",						/* German */
			"error   ",						/* English*/
			"d'erreur",						/* French */
			"fout    ",						/* Dutch  */
		}
	},

	{ /*AKTIV*/
		21,
		{
			"aktiv ",						/* German */
			"activ ",						/* English*/
			"actifs",						/* French */
			"actief",						/* Dutch  */
		}
	},


	{ /*START_FCNOTFOUND*/
		21,
		{
			"FC nicht gefunden!",			/* German */
			"FC not found!",				/* English*/
			"FC pas trouve!",				/* French */
			"FC niet gevonden!",			/* Dutch  */
		}
	},

	{ /*START_FCFOUND*/
		21,
		{
			"PKT-Tool GNU GPL",				/* German */
			"PKT-Tool GNU GPL",				/* English*/
			"PKT-Tool GNU GPL",				/* French */
			"PKT-Tool GNU GPL",				/* Dutch  */
		}
	},

	{ /*START_FCFOUND1*/
		21,
		{
			"gefunden: ",					/* German */
			"found: ",						/* English*/
			"trouvs: ",					/* French */
			"gevonden: ",					/* Dutch  */
		}
	},

	{ /*START_FCFOUND2*/
		21,
		{
			"Flight-Ctrl",					/* German */
			"Flight-Ctrl",					/* English*/
			"Flight-Ctrl",					/* French */
			"Flight-Ctrl",					/* Dutch  */
		}
	},

	{ /*START_FCFOUND3*/
		21,
		{
			"Navi-Ctrl",					/* German */
			"Navi-Ctrl",					/* English*/
			"Navi-Ctrl",					/* French */
			"Navi-Ctrl",					/* Dutch  */
		}
	},

	{ /*START_VERSIONCHECK*/
		21,
		{
			"Version: ",					/* German */
			"Version: ",					/* English*/
			"Version: ",					/* French */
			"Versie:  ",					/* Dutch  */
		}
	},

	{ /*START_VERSIONCHECK1*/
		21,
		{
			"erwartet",						/* German */
			"expected",						/* English*/
			"attendus",						/* French */
			"verwacht",						/* Dutch  */
		}
	},

	{ /*START_VERSIONCHECK2*/
		21,
		{
			"gefunden",						/* German */
			"found   ",						/* English*/
			"trouves ",						/* French */
			"gevonden",						/* Dutch  */
		}
	},

	{ /*START_VERSIONCHECK3*/
		21,
		{
			"PKT-Tool nur mit",				/* German */
			"PKT-Tool only with",			/* English*/
			"PKT uniquement avec",			/* French */
			"PKT-Tool alleen met",			/* Dutch  */
		}
	},

	{ /*START_VERSIONCHECK4*/
		21,
		{
			"FC Software ",					/* German */
			"FC Software ",					/* English*/
			"FC Software ",					/* French */
			"FC Software ",					/* Dutch  */
		}
	},

	{ /*START_VERSIONCHECK5*/
		21,
		{
			"kompatibel",					/* German */
			"compatible",					/* English*/
			"compatibles",					/* French */
			"compatibel",					/* Dutch  */
		}
	},

	{ /*ON*/
		21,
		{
			"Ein  ",						/* German */
			"On   ",						/* English*/
			"Un   ",						/* French */
			"Aan  ",						/* Dutch  */
		}
	},

	{ /*AUS*/
		21,
		{
			"Aus  ",						/* German */
			"Off  ",						/* English*/
			"Du   ",						/* French */
			"Uit  ",						/* Dutch  */
		}
	},

	{ /*ESC*/
		21,
		{
			"ESC",							/* German */
			"ESC",							/* English*/
			"ESC",							/* French */
			"ESC",							/* Dutch  */
		}
	},

	{ /*SHUTDOWN*/
		21,
		{
			"  PKT ausschalten?",			/* German */
			"  shutdown PKT ?",				/* English*/
			"  desactiver PKT ?",			/* French */
			"  PKT uitschakelen ?",			/* Dutch  */
		}
	},

	{ /*YES NO*/
		21,
		{
			"Nein   Ja",					/* German */
			"no    yes",					/* English*/
			"non   oui",					/* French */
			"Nee    Ja",					/* Dutch  */
		}
	},

	{ /*UPDATE1*/
		21,
		{
			"Verbinde PC mit PKT  ",		/* German */
			"Connect PC to PKT-USB",		/* English*/
			"associer PC a PKT-USB",		/* French */
			"Verbind PC met PKT   ",		/* Dutch  */
		}
	},

	{ /*UPDATE2*/
		21,
		{
			"Drcke 'Start' am PKT",		/* German */
			"Press 'Start' on PKT ",		/* English*/
			"presse 'lancer' a PKT",		/* French */
			"Druk 'Start' op PKT  ",		/* Dutch  */
		}
	},

	{ /*ENDSTART*/
		21,
		{
			"           Ende Start",		/* German */
			"           End  Start",		/* English*/
			"          fin  lancer",		/* French */
			"          Einde Start",		/* Dutch  */
		}
	},

	{ /*TOOLS1*/
		21,
		{
			" PC-Quick-Verbindung ",		/* German */
			" PC-Quick-Connection ",		/* English*/
			" PC-connexion rapide ",		/* French */
			" Snelle PC-verbinding",		/* Dutch  */
		}
	},

	{ /*CONNECT1,*/
		21,
		{
			"Verbinde das PKT mit",			/* German */
			"Connect PKT with MK",			/* English*/
			"connectez PKT a  MK",			/* French */
			"Verbind PKT  ",				/* Dutch  */
		}
	},

	{ /*CONNECT2*/
		21,
		{
			"dem MK ber:",					/* German */
			"   over    :",					/* English*/
			"  a propos :",					/* French */
			"   met     :",					/* Dutch  */
		}
	},

	{ /*CONNECT4,*/
		21,
		{
			"dem MK ber:  Kabel, ",		/* German */
			"over: Kabel",					/* English*/
			"a propos: Cable",				/* French */
			"MK via: kabel        ",		/* Dutch  */
		}
	},

	{ /*CONNECT5*/
		21,
		{
			"es ist kein Wi.232",			/* German */
			"there is no Wi.232",			/* English*/
			"l n'ya pas de ",				/* French */
			"er is geen wi.232 ",			/* Dutch  */
		}
	},

	{ /*CONNECT6*/
		21,
		{
			"Modul eingebaut.",				/* German */
			"built in.",					/* English*/
			"module integre Wi232",			/* French */
			"module ingebouwd.",			/* Dutch  */
		}
	},

	{ /*CONNECT7,*/
		21,
		{
			"Wenn doch, dann bitte",		/* German */
			"if yes, then first",			/* English*/
			"Si vous le faites",			/* French */
			"zo ja, dan aub eerst",			/* Dutch  */
		}
	},

	{ /*CONNECT8*/
		21,
		{
			"das Modul zuerst im  ",		/* German */
			"activate modul in",			/* English*/
			"activer le module",			/* French */
			"de module aktiveren",			/* Dutch  */
		}
	},

	{ /*CONNECT9*/
		21,
		{
			"Setupmen aktivieren.",		/* German */
			"Setupmenu",					/* English*/
			"dans menu de config.",			/* French */
			"in het Setupmenu.",			/* Dutch  */
		}
	},

	{ /*CONNECT10*/
		21,
		{
			"Sie mssen das PKT",			/* German */
			"You have to",					/* English*/
			"Vous devez",					/* French */
			"U moet de PKT",				/* Dutch  */
		}
	},

	{ /*CONNECT11*/
		21,
		{
			"jetzt neu starten!",			/* German */
			"restart PKT",					/* English*/
			"redemarrer PKT",				/* French */
			"nu opnieuw starten!",			/* Dutch  */
		}
	},

	{ /*CONNECT12*/
		21,
		{
			"Es ist kein BTM-222",			/* German */
			"There is no BTM-222",			/* English*/
			"l n'ya pas de ",				/* French */
			"Er is geen BTM-222",			/* Dutch  */
		}
	},

	{ /*CONNECT13*/
		21,
		{
			"Modul eingebaut",				/* German */
			"Modul built in",				/* English*/
			"module integre BTM222",		/* French */
			"module ingebouwd.",			/* Dutch  */
		}
	},

	{ /*CONNECT14*/
		21,
		{
			" MK-USB Funktion ",			/* German */
			" MK-USB Function ",			/* English*/
			" MK-USB fonction ",			/* French */
			" MK-USB Functie  ",			/* Dutch  */
		}
	},

	{ /*CONNECT15*/
		21,
		{
			" BT --> Kabel an FC  ",		/* German */
			" BT --> Kabel to FC  ",		/* English*/
			" BT --> Cable a  FC  ",		/* French */
			" BT --> kabel naar FC",		/* Dutch  */
		}
	},

	{ /*CONNECT16*/
		21,
		{
			"PC mit BT verb.",				/* German */
			"connect PC with BT",			/* English*/
			"associer PC a BT",				/* French */
			"PC via BT verbonden.",			/* Dutch  */
		}
	},

	{ /*CONNECT17*/
		21,
		{
			"PKT-Kabel an FC",				/* German */
			"PKT-Kabel to FC",				/* English*/
			"PKT-Cable a FC",				/* French */
			"PKT-kabel naar FC",			/* Dutch  */
		}
	},

	{ /*CONNECT18*/
		21,
		{
			" BT --> Wi.232       ",		/* German */
			" BT --> Wi.232       ",		/* English*/
			" BT --> Wi.232       ",		/* French */
			" BT --> Wi.232       ",		/* Dutch  */
		}
	},

	{ /*CONNECT19*/
		21,
		{
			"Wi.232 an FC         ",		/* German */
			"Wi.232 to FC         ",		/* English*/
			"Wi.232 a FC          ",		/* French */
			"Wi.232 naar FC       ",		/* Dutch  */
		}
	},

	{ /*CONNECT20*/
		21,
		{
			" USB --> Kabel an FC ",		/* German */
			" USB --> cable to FC ",		/* English*/
			" USB --> cable a FC  ",		/* French */
			"USB --> kabel naar FC",		/* Dutch  */
		}
	},

	{ /*CONNECT21*/
		21,
		{
			"PC mit USB verbinden ",		/* German */
			"connect PC with USB  ",		/* English*/
			"associer PC a USB    ",		/* French */
			"Verbind PC met USB   ",		/* Dutch  */
		}
	},

	{ /*CONNECT22*/
		21,
		{
			" USB --> Wi.232      ",		/* German */
			" USB --> Wi.232      ",		/* English*/
			" USB --> Wi.232      ",		/* French */
			" USB --> Wi.232      ",		/* Dutch  */
		}
	},

	{ /*CONNECT23*/
		21,
		{
			"MK-Tool starten",				/* German */
			"start MK-Tool",				/* English*/
			"demarrage MK-Tool",			/* French */
			"start MK-Tool",				/* Dutch  */
		}
	},

	{ /*CONNECT24*/
		21,
		{
			" Wi.232 Konfigurieren",		/* German */
			" Wi.232 Configuration",		/* English*/
			" Wi.232 configurer   ",		/* French */
			" Wi.232 Configuratie ",		/* Dutch  */
		}
	},

	{ /*CONNECT25*/
		21,
		{
			"Programm starten.    ",		/* German */
			"start program ",				/* English*/
			"Dmarrer le programme",		/* French */
			"start programma.",				/* Dutch  */
		}
	},

	{ /*CONNECT26*/
		21,
		{
			"BTM-222 Konfigurieren",		/* German */
			"BTM-222 configuration",		/* English*/
			"BTM-222 de configura.",		/* French */
			"BTM-222 configuratie",			/* Dutch  */
		}
	},

	{ /*CONNECT27*/
		21,
		{
			"FC > MK-USB > BTM-222",		/* German */
			"FC > MK-USB > BTM-222",		/* English*/
			"FC > MK-USB > BTM-222",		/* French */
			"FC > MK-USB > BTM-222",		/* Dutch  */
		}
	},

	{ /*CONNECT28*/
		21,
		{
			"MK-USB an PC anschl. ",		/* German */
			"connect PC to MK-USB ",		/* English*/
			"associer PC a MK-USB ",		/* French */
			"Verbind PC met MK-USB",		/* Dutch  */
		}
	},

	{ /*CONNECT29*/
		21,
		{
			"Zwischen MK-USB und  ",		/* German */
			"connect crossed cable",		/* English*/
			"la connexion entre PC",		/* French */
			"Tussen MK-USB en PKT ",		/* Dutch  */
		}
	},

	{ /*CONNECT30*/
		21,
		{
			"PKT ein gekreuztes   ",		/* German */
			"between MK-USB and   ",		/* English*/
			"et FC un cable croise",		/* French */
			"een gekruiste kabel  ",		/* Dutch  */
		}
	},

	{ /*CONNECT31*/
		21,
		{
			"Kabel anschliessen.  ",		/* German */
			"PKT SV2",						/* English*/
			" ",							/* French */
			"aansluiten.",					/* Dutch  */
		}
	},

	{ /*Kabel*/
		21,
		{
			"Kabel",						/* German */
			"cable",						/* English*/
			"cable",						/* French */
			"Kabel",						/* Dutch  */
		}
	},

	{ /*SLAVE*/
		21,
		{
			"Slave   ",						/* German */
			"Slave   ",						/* English*/
			"esclaves",						/* French */
			"Slave   ",						/* Dutch  */
		}
	},

	{ /*NORMAL*/
		21,
		{
			"Normal ",						/* German */
			"Normal ",						/* English*/
			"normal ",						/* French */
			"Norm.  ",						/* Dutch  */
		}
	},

	{ /*Reverse*/
		21,
		{
			"Reverse",						/* German */
			"inverse",						/* English*/
			"inverse",						/* French */
			"geinver",						/* Dutch  */
		}
	},

	{ /*ENDOK*/
		21,
		{
			"Ende   OK",					/* German */
			"End    OK",					/* English*/
			"Fin    OK",					/* French */
			"Eind   OK",					/* Dutch  */
		}
	},

	{ /*EEPROM1*/
		21,
		{
			" EEProm wirklich",				/* German */
			" Realy delete",				/* English*/
			" eeprom supprimer?",			/* French */
			" Eeprom werkelijk",			/* Dutch  */
		}
	},

	{ /*EEPROM2*/
		21,
		{
			" lschen?",					/* German */
			" EEprom?",						/* English*/
			"    ",							/* French */
			" wissen?",						/* Dutch  */
		}
	},

	{ /*DEUTSCH*/
		21,
		{
			"deutsch    ",					/* German */
			"german     ",					/* English*/
			"allemande  ",					/* French */
			"duits      ",					/* Dutch  */
		}
	},

	{ /*ENGLISCH*/
		21,
		{
			"englisch   ",					/* German */
			"english    ",					/* English*/
			"anglaise   ",					/* French */
			"engels     ",					/* Dutch  */
		}
	},

	{ /*FRANCE*/
		21,
		{
			"franzsisch",					/* German */
			"french     "  ,				/* English*/
			"franaise  ",					/* French */
			"frans      ",					/* Dutch  */
		}
	},

	{ /*NETHERL*/
		21,
		{
			"hollndisch",					/* German */
			"dutch      ",					/* English*/
			"hollandaise",					/* French */
			"nederlands ",					/* Dutch  */
		}
	},

	{ /*DISPLAY1*/
		21,
		{
			"Anzeige Einstellungen",		/* German */
			" Display Setup       ",		/* English*/
			" d'affichage config. ",		/* French */
			"Display instellingen ",		/* Dutch  */
		}
	},

	{ /*DISPLAY2*/
		21,
		{
			"Infos bei Start:",				/* German */
			"Info at startup ",				/* English*/
			"Inf.au demarrage",				/* French */
			"Info bij opstart",				/* Dutch  */
		}
	},

	{ /*DISPLAY3*/
		21,
		{
			"Sprache : ",					/* German */
			"Language: ",					/* English*/
			"la langue: ",					/* French */
			"Taal: ",						/* Dutch  */
		}
	},

	{ /*DISPLAY4*/
		21,
		{
			"Licht aus nach:",				/* German */
			"Light off after:",				/* English*/
			"Exti.feux p.les:",				/* French */
			"Licht uit na:  ",				/* Dutch  */
		}
	},

	{ /*DISPLAY5*/
		21,
		{
			"LCD Helligk.:",				/* German */
			" Brightness :",				/* English*/
			" luminosite :",				/* French */
			" intensiteit:",				/* Dutch  */
		}
	},

	{ /*DISPLAY6*/
		21,
		{
			"LCD Kontrast:",				/* German */
			"LCD contrast:",				/* English*/
			"LCD contrast:",				/* French */
			"LCD contrast:",				/* Dutch  */
		}
	},

	{ /*DISPLAY7*/
		21,
		{
			"LCD Norm/Inv: ",				/* German */
			"LCD Norm/Inv: ",				/* English*/
			"LCD Norm/Inv: ",				/* French */
			"LCD Norm/Inv: ",				/* Dutch  */
		}
	},

	{ /*DISPLAY8*/
		21,
		{
			"LCD Orient.: ",				/* German */
			"LCD Orient.: ",				/* English*/
			"LCD Orient.: ",				/* French */
			"LCD Orient.: ",				/* Dutch  */
		}
	},

	{ /*DISPLAY9*/
		21,
		{
			"RC Fehlerpiep :",				/* German */
			"RC Errorbeep  :",				/* English*/
			"RC Errorbeep  :",				/* French */
			"RC Errorbeep  :",				/* Dutch  */
		}
	},

	{ /*DEBUGPKT*/
		21,
		{
			"Debug PKT",					/* German */
			"Debug PKT",					/* English*/
			"Debug PKT",					/* French */
			"Debug PKT",					/* Dutch  */
		}
	},

	{ /*WITXRX*/
		21,
		{
			"Wi TX/RX Chan:",				/* German */
			"Wi TX/RX Chan:",				/* English*/
			"Wi TX/RX Chan:",				/* French */
			"Wi TX/RX Chan:",				/* Dutch  */
		}
	},

	{ /*WINETG*/
		21,
		{
			"Wi NetW. Grp.:",				/* German */
			"Wi NetW. Grp.:",				/* English*/
			"Wi NetW. Grp.:",				/* French */
			"Wi NetW. Grp.:",				/* Dutch  */
		}
	},

	{ /*WINETM*/
		21,
		{
			"Wi NetW. Mode:",				/* German */
			"Wi NetW. Mode:",				/* English*/
			"Wi NetW. Mode:",				/* French */
			"Wi NetW. Mode:",				/* Dutch  */
		}
	},


	{ /*WITIMEOUT*/
		21,
		{
			"Wi TX Timeout:",				/* German */
			"Wi TX Timeout:",				/* English*/
			"Wi TX Timeout:",				/* French */
			"Wi TX Timeout:",				/* Dutch  */
		}
	},

	{ /*WIUART*/
		21,
		{
			"Wi UART MTU   :",				/* German */
			"Wi UART MTU   :",				/* English*/
			"Wi UART MTU   :",				/* French */
			"Wi UART MTU   :",				/* Dutch  */
		}
	},

	{ /*WI2321*/
		21,
		{
			"Wi.232 eingebaut:",			/* German */
			"Wi.232 built in :",			/* English*/
			"Wi.232 integre  :",			/* French */
			"Wi.232 ingebouwd:",			/* Dutch  */
		}
	},

	{ /*WI2322*/
		21,
		{
			"Ist ein Wi.232-Modul ",		/* German */
			"Is Wi232 modul",				/* English*/
			"est un module ",				/* French */
			"Is er een Wi.232",				/* Dutch  */
		}
	},

	{ /*WI2323*/
		21,
		{
			"eingebaut?",					/* German */
			"built in?",					/* English*/
			"integre Wi232?",				/* French */
			"module ingebouwd?",			/* Dutch  */
		}
	},

	{ /*YES*/
		21,
		{
			"Ja  ",							/* German */
			"yes ",							/* English*/
			"oui ",							/* French */
			"Ja  ",							/* Dutch  */
		}
	},

	{ /*NO*/
		21,
		{
			"Nein",							/* German */
			"no  ",							/* English*/
			"non ",							/* French */
			"Nee ",							/* Dutch  */
		}
	},

	{ /*BT1*/
		21,
		{
			" BTM222 Einstellungen",		/* German */
			"  BTM-222 settings   ",		/* English*/
			"  BTM-222 settings   ",		/* French */
			"  BTM-222 settings   ",		/* Dutch  */
		}
	},

	{ /*BT2*/
		21,
		{
			"Ist ein BTM-222-Modul",		/* German */
			"Is BTM-222 Modul",				/* English*/
			"est un module ",				/* French */
			"Is er een BTM-222",			/* Dutch  */
		}
	},

	{ /*BT3*/
		21,
		{
			"eingebaut?",					/* German */
			"built in?",					/* English*/
			"integre BTM222?",				/* French */
			"module ingebouwd?",			/* Dutch  */
		}
	},

	{ /*BT4*/
		21,
		{
			"BTM222 eingebaut:",			/* German */
			"BTM222 built in :",			/* English*/
			"BTM222 integre  :",			/* French */
			"BTM222 ingebouwd:",			/* Dutch  */
		}
	},


	{ /*LIPO1*/
		21,
		{
			" PKT Akku Einstellung",		/* German */
			" PKT Accu Setup      ",		/* English*/
			" PKT Accu Setup      ",		/* French */
			" PKT Accu Setup      ",		/* Dutch  */
		}
	},

	{ /*LIPO2*/
		21,
		{
			"PKT Akkutyp: ",				/* German */
			"PKT Accutyp: ",				/* English*/
			"PKT Accutyp: ",				/* French */
			"PKT Accutype: ",				/* Dutch  */
		}
	},

	{ /*LIPO3*/
		21,
		{
			"Akku U Offset: ",				/* German */
			"Accu U Offset: ",				/* English*/
			"Accu U Offset: ",				/* French */
			"Accu U Offset: ",				/* Dutch  */
		}
	},

	{ /*LIPO4*/
		21,
		{
			"PKT Akkutyp: ",				/* German */
			"PKT Accutyp: ",				/* English*/
			"PKT Accutyp: ",				/* French */
			"PKT Accutype: ",				/* Dutch  */
		}
	},

	{ /*LIPO5*/
		21,
		{
			"Offset verstellen bis",		/* German */
			"adjust offset until",			/* English*/
			"Decalage l'ajuster ",			/* French */
			"Offset afregelen tot",			/* Dutch  */
		}
	},

	{ /*LIPO6*/
		21,
		{
			"die Spannung passt",			/* German */
			"voltage fits",					/* English*/
			"a la tension",					/* French */
			"de spanning juist is.",		/* Dutch  */
		}
	},

	{ /*LOWBAT*/
		21,
		{
			"LowBat Warn V:",				/* German */
			"LowBat Warn V:",				/* English*/
			"LowBat Warn V:",				/* French */
			"LowBat alarm :",				/* Dutch  */
		}
	},

	{ /*OSD_3D_V, vorne*/
		21,
		{
			"V",							/* German */
			"F",							/* English*/
			"L",							/* French */
			"F",							/* Dutch  */
		}
	},

	{ /*OSD_3D_H, hinten*/
		21,
		{
			"H",							/* German */
			"B",							/* English*/
			"D",							/* French */
			"A",							/* Dutch  */
		}
	},

	{ /*OSD_3D_L, links*/
		21,
		{
			"L",							/* German */
			"L",							/* English*/
			"G",							/* French */
			"L",							/* Dutch  */
		}
	},

	{ /*OSD_3D_R, rechts*/
		21,
		{
			"R",							/* German */
			"R",							/* English*/
			"D",							/* French */
			"R",							/* Dutch  */
		}
	},

	{ /*OSD_3D_NICK, Ni*/
		21,
		{
			"Ni",							/* German */
			"Ni",							/* English*/
			"Ta",							/* French */
			"Ni",							/* Dutch  */
		}
	},

	{ /*OSD_3D_ROLL, Ro*/
		21,
		{
			"Ro",							/* German */
			"Ro",							/* English*/
			"Ro",							/* French */
			"Ro",							/* Dutch  */
		}
	},

	{ /*OSD_3D_COMPASS, Ko*/
		21,
		{
			"Ko",							/* German */
			"Co",							/* English*/
			"Co",							/* French */
			"Co",							/* Dutch  */
		}
	},

	{ /*OSD_ERROR*/
		21,
		{
			"FEHLER: Datenverlust ",		/* German */
			"ERROR: Data lost",				/* English*/
			"perte de donnees",				/* French */
			"verbinding verbroken ",		/* Dutch  */
		}
	},

	{ /*OSD_POS1*/
		21,
		{
			"Letzte bekannte",				/* German */
			"Last known ",					/* English*/
			"Derniere position",			/* French */
			"Laatst bekende",				/* Dutch  */
		}
	},

	{ /*OSD_POS2*/
		21,
		{
			"Position ",					/* German */
			"position ",					/* English*/
			"position ",					/* French */
			"positie ",						/* Dutch  */
		}
	},

	{ /*PARA_SETTINGS*/
		21,
		{
			" Einstellungen       ",		/* German */
			" Setting             ",		/* English*/
			" Parametres          ",		/* French */
			" Instellingen        ",		/* Dutch  */
		}
	},

	{ /*PARA_CHANGE*/
		21,
		{
			"ndern",						/* German */
			"change",						/* English*/
			"le changement",				/* French */
			"verandering",					/* Dutch  */
		}
	},

	{ /*PARA_AKTIVI*/
		21,
		{
			"aktivieren",					/* German */
			"activate",						/* English*/
			"activer",						/* French */
			"activeren",					/* Dutch  */
		}
	},

	{ /*PARA_AKTIV*/
		21,
		{
			"aktiviert",					/* German */
			"activated",					/* English*/
			"activee",						/* French */
			"geactiveerd",					/* Dutch  */
		}
	},

	{ /*PARA_SAVESETT*/
		21,
		{
			" Setting x speichern?",		/* German */
			" store setting?",				/* English*/
			" Reglage magasin?",			/* French */
			" instell.op te slaan?",		/* Dutch  */
		}
	},

	{ /*PARA_SETTSAVED*/
		21,
		{
			"Gespeichert und",				/* German */
			"stored and",					/* English*/
			"stockes et",					/* French */
			"opgeslagen en",				/* Dutch  */
		}
	},

	{ /*PARA_COPY*/
		21,
		{
			"Kopiere Setting",				/* German */
			"copy settings",				/* English*/
			"parametres de copie",			/* French */
			"kopieer instel.",				/* Dutch  */
		}
	},

	{ /*PARA_FROMTO*/
		21,
		{
			" von  x  nach  y",				/* German */
			" from x to y",					/* English*/
			" des x apres y",				/* French */
			" van x na y",					/* Dutch  */
		}
	},

	{ /*PARA_ENDE*/
		21,
		{
			"von   nach  Ende   OK",		/* German */
			"from  to    end    OK",		/* English*/
			"des   apres fin    OK",		/* French */
			"van   na    einde  OK",		/* Dutch  */
		}
	},

	{ /*PARA_COPYQ*/
		21,
		{
			"Wirklich kopieren?",			/* German */
			"really copy?",					/* English*/
			"vraiment copie?",				/* French */
			"echt kopie?",					/* Dutch  */
		}
	},

	{ /*PARA_COPYACTIV*/
		21,
		{
			"Kopiert und aktiviert",		/* German */
			"copied and activated ",		/* English*/
			"copies et actifs",				/* French */
			"Kopien en actief",			/* Dutch  */
		}
	},

	{ /*PARA_CHANGESETT*/
		21,
		{
			"ndere Einstellungen ",		/* German */
			"   change settings   ",		/* English*/
			"modifier les reglages",		/* French */
			"instellingen wijzigen",		/* Dutch  */
		}
	},

	{ /*PARA_SELECT*/
		21,
		{
			" Whle Parameter     ",		/* German */
			" select parameters   ",		/* English*/
			"selectionnez Paramet.",		/* French */
			"Selecteer Parameters ",		/* Dutch  */
		}
	},

	{ /*PARA_SEITE*/
		21,
		{
			" Whle Seite         ",		/* German */
			"     select page     ",		/* English*/
			"Selectionnez la page ",		/* French */
			"  Selecteer pagina   ",		/* Dutch  */
		}
	},

	{ /*PARA_SELSETT*/
		21,
		{
			" Whle Setting:      ",		/* German */
			"  select setting     ",		/* English*/
			"Selectionnez setting ",		/* French */
			"  Selecteer setting  ",		/* Dutch  */
		}
	},

	{ /*GPS1*/
		21,
		{
			"  GPS Einstellungen  ",		/* German */
			"    GPS settings     ",		/* English*/
			"    GPS settings     ",		/* French */
			"    GPS settings     ",		/* Dutch  */
		}
	},

	{ /*GPS2*/
		21,
		{
			"gewhltes GPS Gert  ",		/* German */
			"selected GPS device  ",		/* English*/
			"selected GPS device  ",		/* French */
			"selected GPS device  ",		/* Dutch  */
		}
	},

	{ /*GPS3*/
		21,
		{
			"GPS Empf.einschalten?",		/* German */
			"receive GPS on?      ",		/* English*/
			"receive GPS on?      ",		/* French */
			"receive GPS on?      ",		/* Dutch  */
		}
	},

	{ /*STATS_ITEM_0*/
		21,
		{
			"max Hhe     :",				/* German */
			"max Altitude :",				/* English*/
			"max Altitude :",				/* French */
			"max Altitude :",				/* Dutch  */
		}
	},

	{ /*STATS_ITEM_1*/
		21,
		{
			"max Geschw.  :",				/* German */
			"max Speed    :",				/* English*/
			"max Speed    :",				/* French */
			"max Speed    :",				/* Dutch  */
		}
	},

	{ /*STATS_ITEM_2*/
		21,
		{
			"max Entfern. :",				/* German */
			"max Distance :",				/* English*/
			"max Distance :",				/* French */
			"max Distance :",				/* Dutch  */
		}
	},

	{ /*STATS_ITEM_3*/
		21,
		{
			"min Spannung :",				/* German */
			"min Voltage  :",				/* English*/
			"min Voltage  :",				/* French */
			"min Voltage  :",				/* Dutch  */
		}
	},

	{ /*STATS_ITEM_4*/
		21,
		{
			"max Zeit     :",				/* German */
			"max Time     :",				/* English*/
			"max Time     :",				/* French */
			"max Time     :",				/* Dutch  */
		}
	},

	{ /*STATS_ITEM_5*/
		21,
		{
			"max Strom    :",				/* German */
			"max Current  :",				/* English*/
			"max Current  :",				/* French */
			"max Current  :",				/* Dutch  */
		}
	},

	{ /*STATS_ITEM_6*/
		21,
		{
			"Ent.Kapazitt:",				/* German */
			"UsedCapacity :",				/* English*/
			"UsedCapacity :",				/* French */
			"UsedCapacity :",				/* Dutch  */
		}
	},

	{ /*STATS_ITEM_7*/
		21,
		{
			"Long. :",						/* German */
			"Long. :",						/* English*/
			"Long. :",						/* French */
			"Long. :",						/* Dutch  */
		}
	},

	{ /*STATS_ITEM_8*/
		21,
		{
			"Lat.  :",						/* German */
			"Lat.  :",						/* English*/
			"Lat.  :",						/* French */
			"Lat.  :",						/* Dutch  */
		}
	},

	{ /*ONLY_NC*/
		21,
		{
			"Nur mit NC !  ",				/* German */
			"Only with NC !",				/* English*/
			"Only with NC !",				/* French */
			"Only with NC !",				/* Dutch  */
		}
	},

	{ /*NO_SETTINGS*/
		21,
		{
			"Keine Setings !!  "		,	/* German */
			"No settings read!!"		,	/* English*/
			"Non Parametrs!!  "		,	/* French */
			"No settings read!!"		,	/* Dutch  */
		}
	},

	{ /*OSD_ALTI_0*/
		21,
		{
			"Hhe  aus ",					/* German */
			"Alti. off ",					/* English*/
			"Alti.finir",					/* French */
			"Alti. off ",					/* Dutch  */
		}
	},

	{ /*OSD_ALTI_1*/
		21,
		{
			"Hhe begr.",					/* German */
			"Alti.Limit",					/* English*/
			"Alti.Limit",					/* French */
			"Alti.Limit",					/* Dutch  */
		}
	},

	{ /*OSD_VARIO_0*/
		21,
		{
			"Vario aus ",					/* German */
			"Vario off ",					/* English*/
			"Vario fini",					/* French */
			"Vario off ",					/* Dutch  */
		}
	},

	{ /*OSD_VARIO_1*/
		21,
		{
			"Vario Hhe",					/* German */
			"Vario Alt.",					/* English*/
			"Vario Alt.",					/* French */
			"Vario Alt.",					/* Dutch  */
		}
	},

	{ /*OSD_CARE_FREE_0*/
		21,
		{
			"         ",					/* German */
			"         ",					/* English*/
			"         ",					/* French */
			"         ",					/* Dutch  */
		}
	},

	{ /*OSD_CARE_FREE_1*/
		21,
		{
			"Care Free",					/* German */
			"Care Free",					/* English*/
			"Care Free",					/* French */
			"Care Free",					/* Dutch  */
		}
	},

	{ /*OSD_LED0*/
		21,
		{
			"    ",							/* German */
			"    ",							/* English*/
			"    ",							/* French */
			"    ",							/* Dutch  */
		}
	},

	{ /*OSD_LED1*/
		21,
		{
			"LED1",							/* German */
			"LED1",							/* English*/
			"LED1",							/* French */
			"LED1",							/* Dutch  */
		}
	},

	{ /*OSD_LED2*/
		21,
		{
			"LED2",							/* German */
			"LED2",							/* English*/
			"LED2",							/* French */
			"LED2",							/* Dutch  */
		}
	},

	{ /*OSD_NAVI_MODE_0*/
		21,
		{
			"Navi  aus  ",					/* German */
			"Navi  off  ",					/* English*/
			"Navi  off  ",					/* French */
			"Navi  off  ",					/* Dutch  */
		}
	},

	{ /*OSD_NAVI_MODE_1*/
		21,
		{
			"Pos. halten",					/* German */
			"Pos. Hold  ",					/* English*/
			"Pos. durer ",					/* French */
			"Pos. Hold  ",					/* Dutch  */
		}
	},

	{ /*OSD_NAVI_MODE_2*/
		21,
		{
			"Coming Home",					/* German */
			"Coming Home",					/* English*/
			"Retoure    ",					/* French */
			"Coming Home",					/* Dutch  */
		}
	},

	{ /*OSD_FLAGS_0*/
		21,
		{
			"         ",					/* German */
			"         ",					/* English*/
			"         ",					/* French */
			"         ",					/* Dutch  */
		}
	},

	{ /*OSD_FLAGS_1*/
		21,
		{
			"Justieren",					/* German */
			"Calibrate",					/* English*/
			"Calibrage",					/* French */
			"Calibrate",					/* Dutch  */
		}
	},

	{ /*OSD_FLAGS_2*/
		21,
		{
			"Start    ",					/* German */
			"Start    ",					/* English*/
			"Depart   ",					/* French */
			"Start    ",					/* Dutch  */
		}
	},

	{ /*OSD_FLAGS_3*/
		21,
		{
			"Betrieb  ",					/* German */
			"Run      ",					/* English*/
			"Marcher  ",					/* French */
			"Run      ",					/* Dutch  */
		}
	},

	{ /*OSD_FLAGS_4*/
		21,
		{
			"Fliegen  ",					/* German */
			"Fly      ",					/* English*/
			"Foler    ",					/* French */
			"Fly      ",					/* Dutch  */
		}
	},

	{ /*OSD_FLAGS_5*/
		21,
		{
			"Landung  ",					/* German */
			"Landing  ",					/* English*/
			"Apponter ",					/* French */
			"Landing  ",					/* Dutch  */
		}
	},

	{ /*OSD_FLAGS_6*/
		21,
		{
			"Akku leer",					/* German */
			"Low Bat. ",					/* English*/
			"Low Bat. ",					/* French */
			"Low Bat  ",					/* Dutch  */
		}
	},

	{ /*OSD_Screen*/
		21,
		{
			"  OSD Anzeige Setup  ",		/* German */
			"  OSD screen setup   ",		/* English*/
			"  OSD screen setup   ",		/* French */
			"  OSD screen setup   ",		/* Dutch  */
		}
	},

	{ /*OSD_Invert_Out*/
		21,
		{
			"Out1/2 negiert :",				/* German */
			"Out1/2 inverted:",				/* English*/
			"Out1/2 inverted:",				/* French */
			"Out1/2 inverted:",				/* Dutch  */
		}
	},

	{ /*OSD_LED_Form*/
		21,
		{
			"Out1/2 Format:",				/* German */
			"Out1/2 format:",				/* English*/
			"Out1/2 format:",				/* French */
			"Out1/2 format:",				/* Dutch  */
		}
	},

	{ /*OSD_Send_OSD*/
		21,
		{
//			"Navidata an SV2:",				/* German */
//			"Navidata to SV2:",				/* English*/
//			"Navidata to SV2:",				/* French */
//			"Navidata to SV2:",				/* Dutch  */
			"not implemented:",				/* German */
			"not implemented:",				/* English*/
			"not implemented:",				/* French */
			"not implemented:",				/* Dutch  */
		}
	},
        { /*OSD_Fallspeed*/
                21,
                {
                        "m. Sinkrate m/s:",                               /* German */
                        "m.fallspeed m/s:",                               /* English*/
                        "m.fallspeed m/s:",                               /* French */
                        "m.fallspeed m/s:",                               /* Dutch  */
                }
        },
        { /*OSD_VARIOBEEP*/
                21,
                {
                        "Variometer Beep:",                               /* German */
                        "variometer beep:",                               /* English*/
                        "variometer beep:",                               /* French */
                        "variometer beep:",                               /* Dutch  */
                }
        },
        { /*OSD_HOMEMKVIEW*/
                21,
                {
                        "Homesicht von MK:",                               /* German */
                        "homeview from MK:",                               /* English*/
                        "homeview from MK:",                               /* French */
                        "homeview from MK:",                               /* Dutch  */
                }
        }
};


char const * strGet(int str_no)
{
	return strings[str_no].text[DisplayLanguage];
}




void Test_Language (void)   // bleibt fr Tests
{
	lcd_cls();
	lcd_puts_at(12, 7, strGet(YESNO),0);

	do
	{
		lcd_puts_at(0, 2, strGet(TESTSTRING), 0);
	}
	while(!get_key_press (1 << KEY_ESC));
	get_key_press(KEY_ALL);
	return;
}


